==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/adsapp/nastaveni.php <==
<?php

/**
 * UTF8
 * Funkce jen pro kompatibilitu - muzou se pouzivat v uzivatelskych menu a teoreticky v XML formularich
 */

require_once('adsapp/ronportalsettings.php');

// Spolecne

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_TYP); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleni2() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI2_TYP); }
/**
 * @return int
 * @deprecated
 */
function S_GetJenVlastniRozdeleni2() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI2_JEN_VLASTNI); }
/**
 * @return string
 * @deprecated
 */
function S_GetNadpisRozdeleni2() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI2_NADPIS); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleniZobrazeni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_ZOBRAZENI_TYP);  }
/**
 * @return string
 * @deprecated
 */
function S_GetNadpisRozdeleniZobrazeni() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_ZOBRAZENI_NADPIS);  }
/**
 * @return int
 * @deprecated
 */
function S_GetCoZobrazitRozdeleni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_ZOBRAZENI_CO_ZOBRAZIT);  }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitDochazku() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_DOCHAZKU); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitPuvodni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_PUVODNI); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitZpracovanou() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_ZPRACOVANOU); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitDenniVysledky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_DENNI_VYSLEDKY); }
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitMesicniVysledky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_MESICNI_VYSLEKDY); }
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitMesicniR() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_MESICNI_R); }
/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitKalendar() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_KALENDAR_SMEN); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitHistorii() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_HISTORII_PRUCHODU); }
/**
 * @return int
 * @deprecated
 */
function S_GetVariabilniVysledky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_VARIABILNI); }
/**
 * @return int
 * @deprecated
 */
function S_GetVariabilniDenni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_VARIABILNI_DENNI); }

/**
 * @return int
 * @deprecated
 */
function S_GetADSMzdovePolozky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_MZDOVE_POLOZKY); }
/**
 * @return int
 * @deprecated
 */
function S_GetPlanovaniKapacit() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_KAPACITY); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitEditaciDochazky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::EDITACE_POVOLENA); }

/**
 * @return int
 * @deprecated
 */
function S_GetSkrytZapoctenyCas() { return \Ron\RonPortal\RonPortalSettings::getIntValue('skrytzapoctenycas'); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitPrepsaniZaznamu() { return \Ron\RonPortal\RonPortalSettings::getIntValue('editaceprepisovat'); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleniProEditaci() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::EDITACE_TYP_ROZDELENI); }

/**
 * @return string
 * @deprecated
 */
function S_GetNadpisRozdeleniDochazky() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::EDITACE_NADPIS_ROZDELENI); }

// spousteni agentu
/**
 * @return bool
 * @deprecated
 */
function S_GetSpousteniADS() { return \Ron\RonPortal\RonPortalSettings::getSpousteniADS(); }
function S_GetPersonAgentHost() { global $_person_agenthost;  return $_person_agenthost; }
function S_GetPersonAgentPort() { global $_person_agentport;  return $_person_agentport; }

/**
 * @return string
 * @deprecated
 */
function S_GetNastaveniSloupcuPoctuLidi() { return \Ron\RonPortal\RonPortalSettings::getValue('sloupcepoctulidi'); }

/**
 * @return mixed
 * @deprecated
 */
function S_GetMenuHistorie() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::HISTORIE_MENU); }

/**
 * @return mixed
 * @deprecated
 */
function S_GetSloupceEditaceMesicnich() { return \Ron\RonPortal\RonPortalSettings::getMultilineValue('editacemesicnich'); }

/**
 * @return int
 * @deprecated
 */
function S_GetSchvalovaniAbsenci() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ABSENCE_SCHVALOVANI); }

/**
 * @return int
 * @deprecated
 */
function S_GetOmezeniDochazky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::OMEZENI_DOCHAZKY); }

// sluzebni cesty
/**
 * @return mixed
 * @deprecated
 */
function S_GetPovolitSluzebniCesty() { return \Ron\RonPortal\RonPortalSettings::getIntValue('povolitsluzebnicesty'); }

/**
 * POZOR! Pouzito v XML formularich - docasne ponechat!
 * @return mixed
 * @deprecated
 */
function S_GetTypVypoctuCN() { return \Ron\RonPortal\RonPortalSettings::getIntValue('typvypoctucn'); }
/**
 * POZOR! Pouzito v XML formularich - docasne ponechat!
 * @return mixed
 * @deprecated
 */
function S_GetPrenasetSluzebky() { return \Ron\RonPortal\RonPortalSettings::getIntValue('prenasetsluzebnicesty', 1); }

// Personalistika
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitPersonalistiku() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_PERSONALISTIKU); }
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitHodnoceni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_HODNOCENI); }

/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitVzkazy() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_VZKAZY); }

/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitSkoleni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_SKOLENI); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleniProHodnoceni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::PREDAVANI_TYP_ROZDELENI); }

/**
 * @return mixed|null
 * @deprecated
 */
function S_GetMenuXMLFormulare() { return \Ron\RonPortal\RonPortalSettings::getValue('menuxmlformulare'); }
/**
 * ? Pouziva se to nekde?
 * @return int
 * @deprecated
 */
function S_GetHodnoceniUkolu() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::HODNOCENI_UKOLU); }

/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitDokumenty() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_DOKUMENTY); }

/**
 * @deprecated
 * @return int
 */
function S_GetZobrazitDovednosti() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_DOVEDNOSTI); }

/**
 * @deprecated
 */
function nactiNastaveniZSession() {
    \Ron\RonPortal\RonPortalSettings::getInstance() ->loadFromSession();
}


/**
 * @param \Ron\DB\Database $database
 * @deprecated
 */
function nactiNastaveni($database)
{
    \Ron\RonPortal\RonPortalSettings::getInstance() ->load($database);
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/adsapp/nastaveni.php <==
<?php

/**
 * UTF8
 * Funkce jen pro kompatibilitu - muzou se pouzivat v uzivatelskych menu a teoreticky v XML formularich
 */

// Spolecne

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_TYP); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleni2() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI2_TYP); }
/**
 * @return int
 * @deprecated
 */
function S_GetJenVlastniRozdeleni2() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI2_JEN_VLASTNI); }
/**
 * @return string
 * @deprecated
 */
//function S_GetNadpisRozdeleni2() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI2_NADPIS); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleniZobrazeni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_ZOBRAZENI_TYP);  }
/**
 * @return string
 * @deprecated
 */
function S_GetNadpisRozdeleniZobrazeni() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_ZOBRAZENI_NADPIS);  }
/**
 * @return int
 * @deprecated
 */
function S_GetCoZobrazitRozdeleni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ROZDELENI_ZOBRAZENI_CO_ZOBRAZIT);  }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitDochazku() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_DOCHAZKU); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitPuvodni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_PUVODNI); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitZpracovanou() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_ZPRACOVANOU); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitDenniVysledky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_DENNI_VYSLEDKY); }
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitMesicniVysledky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_MESICNI_VYSLEKDY); }
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitMesicniR() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_MESICNI_R); }
/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitKalendar() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_KALENDAR_SMEN); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitHistorii() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_HISTORII_PRUCHODU); }
/**
 * @return int
 * @deprecated
 */
function S_GetVariabilniVysledky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_VARIABILNI); }
/**
 * @return int
 * @deprecated
 */
function S_GetVariabilniDenni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_VARIABILNI_DENNI); }

/**
 * @return int
 * @deprecated
 */
function S_GetADSMzdovePolozky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_MZDOVE_POLOZKY); }
/**
 * @return int
 * @deprecated
 */
function S_GetPlanovaniKapacit() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_KAPACITY); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitEditaciDochazky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::EDITACE_POVOLENA); }

/**
 * @return int
 * @deprecated
 */
function S_GetSkrytZapoctenyCas() { return \Ron\RonPortal\RonPortalSettings::getIntValue('skrytzapoctenycas'); }

/**
 * @return int
 * @deprecated
 */
function S_GetPovolitPrepsaniZaznamu() { return \Ron\RonPortal\RonPortalSettings::getIntValue('editaceprepisovat'); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleniProEditaci() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::EDITACE_TYP_ROZDELENI); }

/**
 * @return string
 * @deprecated
 */
function S_GetNadpisRozdeleniDochazky() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::EDITACE_NADPIS_ROZDELENI); }

// spousteni agentu
/**
 * @return bool
 * @deprecated
 */
function S_GetSpousteniADS() { return \Ron\RonPortal\RonPortalSettings::getSpousteniADS(); }
function S_GetPersonAgentHost() { global $_person_agenthost;  return $_person_agenthost; }
function S_GetPersonAgentPort() { global $_person_agentport;  return $_person_agentport; }

/**
 * @return string
 * @deprecated
 */
function S_GetNastaveniSloupcuPoctuLidi() { return \Ron\RonPortal\RonPortalSettings::getValue('sloupcepoctulidi'); }

/**
 * @return mixed
 * @deprecated
 */
function S_GetMenuHistorie() { return \Ron\RonPortal\RonPortalSettings::getValue(\Ron\RonPortal\RonPortalSettings::HISTORIE_MENU); }

/**
 * @return mixed
 * @deprecated
 */
function S_GetSloupceEditaceMesicnich() { return \Ron\RonPortal\RonPortalSettings::getMultilineValue('editacemesicnich'); }

/**
 * @return int
 * @deprecated
 */
function S_GetSchvalovaniAbsenci() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ABSENCE_SCHVALOVANI); }

/**
 * @return int
 * @deprecated
 */
function S_GetOmezeniDochazky() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::OMEZENI_DOCHAZKY); }

// sluzebni cesty
/**
 * @return mixed
 * @deprecated
 */
function S_GetPovolitSluzebniCesty() { return \Ron\RonPortal\RonPortalSettings::getIntValue('povolitsluzebnicesty'); }

/**
 * POZOR! Pouzito v XML formularich - docasne ponechat!
 * @return mixed
 * @deprecated
 */
function S_GetTypVypoctuCN() { return \Ron\RonPortal\RonPortalSettings::getIntValue('typvypoctucn'); }
/**
 * POZOR! Pouzito v XML formularich - docasne ponechat!
 * @return mixed
 * @deprecated
 */
function S_GetPrenasetSluzebky() { return \Ron\RonPortal\RonPortalSettings::getIntValue('prenasetsluzebnicesty', 1); }

// Personalistika
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitPersonalistiku() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_PERSONALISTIKU); }
/**
 * @return int
 * @deprecated
 */
function S_GetPovolitHodnoceni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::POVOLIT_HODNOCENI); }

/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitVzkazy() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_VZKAZY); }

/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitSkoleni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_SKOLENI); }

/**
 * @return int
 * @deprecated
 */
function S_GetTypRozdeleniProHodnoceni() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::PREDAVANI_TYP_ROZDELENI); }

/**
 * @return mixed|null
 * @deprecated
 */
function S_GetMenuXMLFormulare() { return \Ron\RonPortal\RonPortalSettings::getValue('menuxmlformulare'); }
/**
 * ? Pouziva se to nekde?
 * @return int
 * @deprecated
 */
function S_GetHodnoceniUkolu() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::HODNOCENI_UKOLU); }

/**
 * @return int
 * @deprecated
 */
function S_GetZobrazitDokumenty() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_DOKUMENTY); }

/**
 * @deprecated
 * @return int
 */
function S_GetZobrazitDovednosti() { return \Ron\RonPortal\RonPortalSettings::getIntValue(\Ron\RonPortal\RonPortalSettings::ZOBRAZIT_DOVEDNOSTI); }

/**
 * @deprecated
 */
function nactiNastaveniZSession() {
    \Ron\RonPortal\RonPortalSettings::getInstance() ->loadFromSession();
}


/**
 * @param \Ron\DB\Database $database
 * @deprecated
 */
function nactiNastaveni($database)
{
    \Ron\RonPortal\RonPortalSettings::getInstance() ->load($database);
}
